@@ -31,7 +31,7 @@ var searchData=
   ['buffer_5fid_28',['buffer_id',['../structspa__io__buffers.html#aadfe10a114c998d88137450877d8326b',1,'spa_io_buffers']]],
   ['buffered_29',['buffered',['../structpw__time.html#a4ad8ba0afa44dc283d8ecd5ea1e9d0ff',1,'pw_time']]],
   ['buffers_30',['Buffers',['../group__pw__buffers.html',1,'Buffers'],['../group__spa__buffer.html',1,'Buffers'],['../page_spa_buffer.html',1,'SPA Buffers']]],
-  ['buffers_31',['buffers',['../structpw__buffers.html#adf149a809c1ea9c435ae7439391c87ed',1,'pw_buffers']]],
+  ['buffers_31',['buffers',['../structpw__buffers.html#adf149a809c1ea9c435ae7439391c87ed',1,'pw_buffers::buffers'],['../structspa__io__async__buffers.html#a97004192f552cb50fee39067e5b07fff',1,'spa_io_async_buffers::buffers']]],
   ['buffers_2dtypes_2eh_32',['buffers-types.h',['../buffers-types_8h.html',1,'']]],
   ['buffers_2eh_33',['buffers.h',['../spa_2include_2spa_2param_2buffers_8h.html',1,'(Global Namespace)'],['../src_2pipewire_2buffers_8h.html',1,'(Global Namespace)']]],
   ['builder_34',['builder',['../structspa__result__device__params__data.html#aacff758b17616a531f27a4b8361142ce',1,'spa_result_device_params_data::builder'],['../structspa__result__node__params__data.html#ad11bffd25122b0ca2fef3ac7c360728c',1,'spa_result_node_params_data::builder']]],
